Cpal

Struct Cpal 

pub struct Cpal<'a> {
    data: FontData<'a>,
}
Fields

data: FontData<'a>

Implementations

Source

impl<'a> Cpal<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn version(&self) -> u16

Table version number (=0).

pub fn num_palette_entries(&self) -> u16

Number of palette entries in each palette.

pub fn num_palettes(&self) -> u16

Number of palettes in the table.

pub fn num_color_records(&self) -> u16

Total number of color records, combined for all palettes.

pub fn color_records_array_offset(&self) -> Nullable<Offset32>

Offset from the beginning of CPAL table to the first ColorRecord.

pub fn color_records_array( &self, ) -> Option<Result<&'a [ColorRecord], ReadError>>

Attempt to resolve color_records_array_offset.

pub fn color_record_indices(&self) -> &'a [BigEndian<u16>]

Index of each palette’s first color record in the combined color record array.

pub fn palette_types_array_offset(&self) -> Option<Nullable<Offset32>>

Offset from the beginning of CPAL table to the Palette Types Array.

This is an array of 32-bit flag fields that describe properties of each palette.

pub fn palette_types_array( &self, ) -> Option<Result<&'a [BigEndian<PaletteType>], ReadError>>

Attempt to resolve palette_types_array_offset.

pub fn palette_labels_array_offset(&self) -> Option<Nullable<Offset32>>

Offset from the beginning of CPAL table to the Palette Labels Array.

This is an array of ‘name’ table IDs (typically in the font-specific name ID range) that specify user interface strings associated with each palette. Use 0xFFFF if no name ID is provided for a palette.

pub fn palette_labels_array( &self, ) -> Option<Result<&'a [BigEndian<NameId>], ReadError>>

Attempt to resolve palette_labels_array_offset.

pub fn palette_entry_labels_array_offset(&self) -> Option<Nullable<Offset32>>

Offset from the beginning of CPAL table to the Palette Entry Labels Array.

This is an array of ‘name’ table IDs (typically in the font-specific name ID range) that specify user interface strings associated with each palette entry, e.g. “Outline”, “Fill”. This set of palette entry labels applies to all palettes in the font. Use 0xFFFF if no name ID is provided for a palette entry.

pub fn palette_entry_labels_array( &self, ) -> Option<Result<&'a [BigEndian<NameId>], ReadError>>

pub fn version_byte_range(&self) -> Range<usize>

pub fn num_palette_entries_byte_range(&self) -> Range<usize>

pub fn num_palettes_byte_range(&self) -> Range<usize>

pub fn num_color_records_byte_range(&self) -> Range<usize>

pub fn color_records_array_offset_byte_range(&self) -> Range<usize>

pub fn color_record_indices_byte_range(&self) -> Range<usize>

pub fn palette_types_array_offset_byte_range(&self) -> Range<usize>

pub fn palette_labels_array_offset_byte_range(&self) -> Range<usize>

pub fn palette_entry_labels_array_offset_byte_range(&self) -> Range<usize>